@@ -1,9 +1,10 @@
-from palp.spider import JumpSpider
+from palp.tool.spider_check import Checker
+from palp.spider.spider_jump import JumpSpider
 from palp.spider.spider_cycle import CycleSpider
 from palp.tool.alarm import send_email
 from palp.tool.alarm import send_dingtalk
 from palp.tool import start_spider
-from palp.item.item import Item
+from palp.item.item import Item, Field
 from palp.item.item_strict import StrictItem
 from palp.item.item_lazy import LazyItem
 from palp.network.request import Request
@@ -15,4 +16,3 @@ from palp.network.request_method import RequestGet, RequestPost
 from palp.middleware.middleware_spider import SpiderMiddleware
 from palp.middleware.middleware_request import RequestMiddleware
 from palp.exception import DropItemException, DropRequestException
-from palp.item.item import Field
